ArtNet. Packet. ArtDataReply
(ArtNet v0.1.0)
Replies to ArtNet.Packet.ArtDataRequest with manufacturer-specific data.
The payload_length field must match the number of bytes in payload.
Packet layout
| Part | Field | Description | Default | Size | Format |
|---|---|---|---|---|---|
| Header | id | fixed | 8 bytes | "Art-Net\\0" | |
| Header | op_code | 0x2800 | 2 bytes | little-endian OpCode | |
| Header | prot_ver | 14 | 2 bytes | protocol version | |
| Payload | esta_manufacturer | ESTA manufacturer code associated with the data reply. | required | 2 bytes | unsigned integer (16 bits) |
| Payload | oem | OEM code associated with the data reply. | required | 2 bytes | unsigned integer (16 bits) |
| Payload | request | Data request identifier being answered. | required | 2 bytes | unsigned integer (16 bits) |
| Payload | payload_length | Number of bytes in the payload field. | required | 2 bytes | unsigned integer (16 bits) |
| Payload | payload | Reply payload bytes. | required | variable (1 byte each) | list of unsigned integer (8 bits) |
Summary
Functions
Decodes a complete Art-Net binary as this packet type.
Encodes this packet struct into a complete Art-Net binary.
Builds a validated packet struct from a map or keyword list.
Builds a validated packet struct from a map or keyword list.
Returns the Art-Net OpCode value for this packet module.
Returns whether this packet includes the Art-Net protocol version header.
Returns the packet payload schema in declaration order.
Types
Functions
Decodes a complete Art-Net binary as this packet type.
Encodes this packet struct into a complete Art-Net binary.
@spec new(map() | Keyword.t()) :: {:ok, t()} | {:error, ArtNet.EncodeError.t()}
Builds a validated packet struct from a map or keyword list.
Builds a validated packet struct from a map or keyword list.
Raises ArtNet.EncodeError when validation fails.
@spec op_code() :: pos_integer()
Returns the Art-Net OpCode value for this packet module.
The OpCode is 0x2800.
@spec require_version_header?() :: boolean()
Returns whether this packet includes the Art-Net protocol version header.
Returns the packet payload schema in declaration order.