ArtNet.Packet.ArtMediaPatch (ArtNet v0.1.0)

Sends media patch information to a media server.

Controllers use this packet to map media server layers and outputs for Art-Net media extensions.

Packet layout

PartFieldDescriptionDefaultSizeFormat
Headeridfixed8 bytes"Art-Net\\0"
Headerop_code0x91002 byteslittle-endian OpCode
Headerprot_ver142 bytesprotocol version
Payloadfiller1Reserved byte, transmitted as zero.01 byteunsigned integer (8 bits)
Payloadfiller2Reserved byte, transmitted as zero.01 byteunsigned integer (8 bits)
Payloadfiller3Reserved byte, transmitted as zero.01 byteunsigned integer (8 bits)
Payloadfiller4Reserved byte, transmitted as zero.01 byteunsigned integer (8 bits)
PayloadstreamMedia stream identifier.required1 byteunsigned integer (8 bits)
Payloadpatch_commandMedia patch command code.required1 byteunsigned integer (8 bits)
Payloadvirtual_delta_xVirtual X coordinate delta.required2 bytesunsigned integer (16 bits)
Payloadvirtual_delta_yVirtual Y coordinate delta.required2 bytesunsigned integer (16 bits)
Payloadcoordinate_countNumber of coordinate entries in the payload.required2 bytesunsigned integer (16 bits)
PayloadaperturePatch aperture value.required1 byteunsigned integer (8 bits)
PayloaddiameterPatch diameter value.required1 byteunsigned integer (8 bits)
PayloadcoordinatesPacked media patch coordinate data.requiredvariable (1 byte each)list of unsigned integer (8 bits)

Summary

Functions

Decodes a complete Art-Net binary as this packet type.

Encodes this packet struct into a complete Art-Net binary.

Builds a validated packet struct from a map or keyword list.

Builds a validated packet struct from a map or keyword list.

Returns the Art-Net OpCode value for this packet module.

Returns whether this packet includes the Art-Net protocol version header.

Returns the packet payload schema in declaration order.

Types

t()

@type t() :: %ArtNet.Packet.ArtMediaPatch{
  aperture: :integer,
  coordinate_count: :integer,
  coordinates: [:integer],
  diameter: :integer,
  filler1: :integer,
  filler2: :integer,
  filler3: :integer,
  filler4: :integer,
  patch_command: :integer,
  stream: :integer,
  virtual_delta_x: :integer,
  virtual_delta_y: :integer
}

Functions

decode(data)

@spec decode(binary()) :: {:ok, t()} | :error

Decodes a complete Art-Net binary as this packet type.

encode(packet)

@spec encode(t()) :: {:ok, binary()} | :error

Encodes this packet struct into a complete Art-Net binary.

new(attrs)

@spec new(map() | Keyword.t()) :: {:ok, t()} | {:error, ArtNet.EncodeError.t()}

Builds a validated packet struct from a map or keyword list.

new!(attrs)

@spec new!(map() | Keyword.t()) :: t()

Builds a validated packet struct from a map or keyword list.

Raises ArtNet.EncodeError when validation fails.

op_code()

@spec op_code() :: pos_integer()

Returns the Art-Net OpCode value for this packet module.

The OpCode is 0x9100.

require_version_header?()

@spec require_version_header?() :: boolean()

Returns whether this packet includes the Art-Net protocol version header.

schema()

Returns the packet payload schema in declaration order.