ArtNet. Packet. ArtPoll
(ArtNet v0.1.0)
Discovers Art-Net nodes on the network.
Controllers broadcast this packet to ask nodes to identify themselves. Nodes
respond with ArtNet.Packet.ArtPollReply.
Packet layout
| Part | Field | Description | Default | Size | Format |
|---|---|---|---|---|---|
| Header | id | fixed | 8 bytes | "Art-Net\\0" | |
| Header | op_code | 0x2000 | 2 bytes | little-endian OpCode | |
| Header | prot_ver | 14 | 2 bytes | protocol version | |
| Payload | talk_to_me | Poll reply behavior flags. | required | 1 byte | ArtNet.Packet.BitField.TalkToMe bit field |
| Payload | priority | Minimum diagnostic priority requested from nodes. | :dp_all | 1 byte | ArtNet.Packet.EnumTable.Priority enum |
| Payload | target_port_address_top | Upper bound of the targeted Port-Address range. | 0 | 2 bytes | unsigned integer (16 bits) |
| Payload | target_port_address_bottom | Lower bound of the targeted Port-Address range. | 0 | 2 bytes | unsigned integer (16 bits) |
| Payload | esta_manufacturer | ESTA manufacturer code filter for targeted polling. | 0 | 2 bytes | unsigned integer (16 bits) |
| Payload | oem | OEM code filter for targeted polling. | 0 | 2 bytes | unsigned integer (16 bits) |
Summary
Functions
Decodes a complete Art-Net binary as this packet type.
Encodes this packet struct into a complete Art-Net binary.
Builds a validated packet struct from a map or keyword list.
Builds a validated packet struct from a map or keyword list.
Returns the Art-Net OpCode value for this packet module.
Returns whether this packet includes the Art-Net protocol version header.
Returns the packet payload schema in declaration order.
Types
@type t() :: %ArtNet.Packet.ArtPoll{ esta_manufacturer: :integer, oem: :integer, priority: ArtNet.Packet.EnumTable.Priority.type(), talk_to_me: ArtNet.Packet.BitField.TalkToMe.t(), target_port_address_bottom: :integer, target_port_address_top: :integer }
Functions
Decodes a complete Art-Net binary as this packet type.
Encodes this packet struct into a complete Art-Net binary.
@spec new(map() | Keyword.t()) :: {:ok, t()} | {:error, ArtNet.EncodeError.t()}
Builds a validated packet struct from a map or keyword list.
Builds a validated packet struct from a map or keyword list.
Raises ArtNet.EncodeError when validation fails.
@spec op_code() :: pos_integer()
Returns the Art-Net OpCode value for this packet module.
The OpCode is 0x2000.
@spec require_version_header?() :: boolean()
Returns whether this packet includes the Art-Net protocol version header.
Returns the packet payload schema in declaration order.