ArtNet.Packet.ArtRdm (ArtNet v0.1.0)

Carries non-discovery RDM messages over Art-Net.

Use this packet for RDM traffic that is not part of the RDM discovery process.

Packet layout

PartFieldDescriptionDefaultSizeFormat
Headeridfixed8 bytes"Art-Net\\0"
Headerop_code0x83002 byteslittle-endian OpCode
Headerprot_ver142 bytesprotocol version
Payloadrdm_versionRDM protocol version.11 byteunsigned integer (8 bits)
Payloadfiller2Reserved byte, transmitted as zero.01 byteunsigned integer (8 bits)
PayloadspareReserved bytes, transmitted as zero.<<0, 0, 0, 0, 0>>5 bytesbinary (5 bytes)
Payloadfifo_availableNumber of RDM messages available in the node FIFO.01 byteunsigned integer (8 bits)
Payloadfifo_maxMaximum RDM FIFO capacity.01 byteunsigned integer (8 bits)
PayloadnetBits 8-14 of the 15-bit Port-Address.01 byteunsigned integer (8 bits)
PayloadcommandRDM command action.:ar_process1 byteArtNet.Packet.EnumTable.RdmCommand enum
PayloadaddressLow byte of the target Port-Address.required1 byteunsigned integer (8 bits)
Payloadrdm_packetEmbedded RDM packet bytes.requiredvariable (1 byte each)list of unsigned integer (8 bits)

Summary

Functions

Decodes a complete Art-Net binary as this packet type.

Encodes this packet struct into a complete Art-Net binary.

Builds a validated packet struct from a map or keyword list.

Builds a validated packet struct from a map or keyword list.

Returns the Art-Net OpCode value for this packet module.

Returns whether this packet includes the Art-Net protocol version header.

Returns the packet payload schema in declaration order.

Types

t()

@type t() :: %ArtNet.Packet.ArtRdm{
  address: :integer,
  command: ArtNet.Packet.EnumTable.RdmCommand.type(),
  fifo_available: :integer,
  fifo_max: :integer,
  filler2: :integer,
  net: :integer,
  rdm_packet: [:integer],
  rdm_version: :integer,
  spare: :binary
}

Functions

decode(data)

@spec decode(binary()) :: {:ok, t()} | :error

Decodes a complete Art-Net binary as this packet type.

encode(packet)

@spec encode(t()) :: {:ok, binary()} | :error

Encodes this packet struct into a complete Art-Net binary.

new(attrs)

@spec new(map() | Keyword.t()) :: {:ok, t()} | {:error, ArtNet.EncodeError.t()}

Builds a validated packet struct from a map or keyword list.

new!(attrs)

@spec new!(map() | Keyword.t()) :: t()

Builds a validated packet struct from a map or keyword list.

Raises ArtNet.EncodeError when validation fails.

op_code()

@spec op_code() :: pos_integer()

Returns the Art-Net OpCode value for this packet module.

The OpCode is 0x8300.

require_version_header?()

@spec require_version_header?() :: boolean()

Returns whether this packet includes the Art-Net protocol version header.

schema()

Returns the packet payload schema in declaration order.