ArtNet. Packet. ArtVideoSetup
(ArtNet v0.1.0)
Sends video screen setup information for extended video features.
The packet configures screen control, font, window, and cursor parameters.
Packet layout
| Part | Field | Description | Default | Size | Format |
|---|---|---|---|---|---|
| Header | id | fixed | 8 bytes | "Art-Net\\0" | |
| Header | op_code | 0xA010 | 2 bytes | little-endian OpCode | |
| Header | prot_ver | 14 | 2 bytes | protocol version | |
| Payload | filler | Reserved bytes, transmitted as zero. | <<0, 0, 0, 0>> | 4 bytes | binary (4 bytes) |
| Payload | control | Video setup control flags. | required | 1 byte | unsigned integer (8 bits) |
| Payload | font_height | Font glyph height in pixels. | required | 1 byte | unsigned integer (8 bits) |
| Payload | first_font | First font glyph index included in the packet. | required | 1 byte | unsigned integer (8 bits) |
| Payload | last_font | Last font glyph index included in the packet. | required | 1 byte | unsigned integer (8 bits) |
| Payload | windows_font_name | Windows font name for the video setup. | required | 64 bytes | null-padded string (64 bytes) |
| Payload | font_data | Packed font glyph data bytes. | required | variable (1 byte each) | list of unsigned integer (8 bits) |
Summary
Functions
Decodes a complete Art-Net binary as this packet type.
Encodes this packet struct into a complete Art-Net binary.
Builds a validated packet struct from a map or keyword list.
Builds a validated packet struct from a map or keyword list.
Returns the Art-Net OpCode value for this packet module.
Returns whether this packet includes the Art-Net protocol version header.
Returns the packet payload schema in declaration order.
Types
@type t() :: %ArtNet.Packet.ArtVideoSetup{ control: :integer, filler: :binary, first_font: :integer, font_data: [:integer], font_height: :integer, last_font: :integer, windows_font_name: String.t() }
Functions
Decodes a complete Art-Net binary as this packet type.
Encodes this packet struct into a complete Art-Net binary.
@spec new(map() | Keyword.t()) :: {:ok, t()} | {:error, ArtNet.EncodeError.t()}
Builds a validated packet struct from a map or keyword list.
Builds a validated packet struct from a map or keyword list.
Raises ArtNet.EncodeError when validation fails.
@spec op_code() :: pos_integer()
Returns the Art-Net OpCode value for this packet module.
The OpCode is 0xA010.
@spec require_version_header?() :: boolean()
Returns whether this packet includes the Art-Net protocol version header.
Returns the packet payload schema in declaration order.