ArtNet. Packet. BitField. GoodInput
(ArtNet v0.1.0)
GoodInput bit field used by ArtNet.Packet.ArtPollReply.
The packet contains one GoodInput value for each of the four reported
ports. Each boolean describes the input state of that port.
Bit size
This bit field is encoded in 8 bits.
Bit layout
| Field | Description | Bits | Default | Value |
|---|---|---|---|---|
convert_sacn | Input is converting sACN to Art-Net. | 0 | required | boolean flag |
receive_errors | Receive errors have been detected. | 2 | required | boolean flag |
input_disabled | Input is disabled. | 3 | required | boolean flag |
dmx_text | DMX text packets have been received. | 4 | required | boolean flag |
dmx_sip | DMX SIP packets have been received. | 5 | required | boolean flag |
dmx_test_packet | DMX test packets have been received. | 6 | required | boolean flag |
data_received | Data has been received. | 7 | required | boolean flag |
Summary
Functions
Returns the bit-field schema in declaration order.
Returns the total number of bits encoded by this bit field.
Decodes an unsigned integer into this bit-field struct.
Encodes this bit-field struct into an unsigned integer.
Types
Functions
@spec bit_field_schema() :: [ {key :: atom(), {ArtNet.Packet.BitField.schema_type(), {start_bit :: non_neg_integer(), length :: pos_integer()}}} ]
Returns the bit-field schema in declaration order.
@spec bit_size() :: pos_integer()
Returns the total number of bits encoded by this bit field.
This bit field is encoded in 8 bits.
@spec decode(non_neg_integer()) :: {:ok, t()} | :error
Decodes an unsigned integer into this bit-field struct.
@spec encode(t()) :: {:ok, non_neg_integer()} | :error
Encodes this bit-field struct into an unsigned integer.