ArtNet. Packet. BitField. GoodOutputB
(ArtNet v0.1.0)
GoodOutputB bit field used by ArtNet.Packet.ArtPollReply.
The packet contains one GoodOutputB value for each of the four reported
ports. These bits extend the output status reported by GoodOutput.
Bit size
This bit field is encoded in 8 bits.
Bit layout
| Field | Description | Bits | Default | Value |
|---|---|---|---|---|
background_discovery_disabled | RDM background discovery is disabled. | 4 | false | boolean flag |
discovery_not_running | Background discovery is not currently running. | 5 | false | boolean flag |
continuous_output_style | Port uses continuous output style. | 6 | false | boolean flag |
rdm_disabled | RDM is disabled on the output. | 7 | false | boolean flag |
Summary
Functions
Returns the bit-field schema in declaration order.
Returns the total number of bits encoded by this bit field.
Decodes an unsigned integer into this bit-field struct.
Encodes this bit-field struct into an unsigned integer.
Types
Functions
@spec bit_field_schema() :: [ {key :: atom(), {ArtNet.Packet.BitField.schema_type(), {start_bit :: non_neg_integer(), length :: pos_integer()}}} ]
Returns the bit-field schema in declaration order.
@spec bit_size() :: pos_integer()
Returns the total number of bits encoded by this bit field.
This bit field is encoded in 8 bits.
@spec decode(non_neg_integer()) :: {:ok, t()} | :error
Decodes an unsigned integer into this bit-field struct.
@spec encode(t()) :: {:ok, non_neg_integer()} | :error
Encodes this bit-field struct into an unsigned integer.