ArtNet. Packet. BitField. TalkToMe
(ArtNet v0.1.0)
TalkToMe bit field used by ArtNet.Packet.ArtPoll.
This field tells nodes how the controller wants ArtPollReply responses and
diagnostics to be sent.
Bit size
This bit field is encoded in 8 bits.
Bit layout
| Field | Description | Bits | Default | Value |
|---|---|---|---|---|
reply_on_change | Send replies when node conditions change. | 1 | required | boolean flag |
diagnostics | Send diagnostics messages. | 2 | required | boolean flag |
diag_unicast | Send diagnostics by unicast. | 3 | required | boolean flag |
vlc | Include VLC transmission support in discovery. | 4 | required | boolean flag |
targeted_mode | Use targeted mode fields in ArtPoll. | 5 | false | boolean flag |
Summary
Functions
Returns the bit-field schema in declaration order.
Returns the total number of bits encoded by this bit field.
Decodes an unsigned integer into this bit-field struct.
Encodes this bit-field struct into an unsigned integer.
Types
Functions
@spec bit_field_schema() :: [ {key :: atom(), {ArtNet.Packet.BitField.schema_type(), {start_bit :: non_neg_integer(), length :: pos_integer()}}} ]
Returns the bit-field schema in declaration order.
@spec bit_size() :: pos_integer()
Returns the total number of bits encoded by this bit field.
This bit field is encoded in 8 bits.
@spec decode(non_neg_integer()) :: {:ok, t()} | :error
Decodes an unsigned integer into this bit-field struct.
@spec encode(t()) :: {:ok, non_neg_integer()} | :error
Encodes this bit-field struct into an unsigned integer.