ArtNet. Packet. EnumTable. FailsafeState
(ArtNet v0.1.0)
Failsafe state values used by ArtNet.Packet.BitField.Status3.
Values
| Atom | Description | Value |
|---|---|---|
hold_last | Hold the last output state. | 0x0 / 0b00 |
all_zero | Drive all output levels to zero. | 0x1 / 0b01 |
all_full | Drive all output levels to full. | 0x2 / 0b10 |
playback_scene | Play the recorded failsafe scene. | 0x3 / 0b11 |
Summary
Functions
Returns the integer code for :all_full.
Returns the integer code for :all_zero.
Returns the number of bits used to encode values in this enum table.
Returns the integer code for :hold_last.
Returns the integer code for :playback_scene.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Types
Functions
@spec all_full() :: non_neg_integer()
Returns the integer code for :all_full.
The code is 0x2.
@spec all_zero() :: non_neg_integer()
Returns the integer code for :all_zero.
The code is 0x1.
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
@spec hold_last() :: non_neg_integer()
Returns the integer code for :hold_last.
The code is 0x0.
@spec playback_scene() :: non_neg_integer()
Returns the integer code for :playback_scene.
The code is 0x3.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.