ArtNet. Packet. EnumTable. FirmwareMasterType
(ArtNet v0.1.0)
Firmware transfer block types used by ArtNet.Packet.ArtFirmwareMaster.
Values
| Atom | Description | Value |
|---|---|---|
firm_first | First firmware block. | 0x0 / 0b00000000 |
firm_cont | Continuation firmware block. | 0x1 / 0b00000001 |
firm_last | Final firmware block. | 0x2 / 0b00000010 |
ubea_first | First UBEA block. | 0x3 / 0b00000011 |
ubea_cont | Continuation UBEA block. | 0x4 / 0b00000100 |
ubea_last | Final UBEA block. | 0x5 / 0b00000101 |
Summary
Functions
Returns the number of bits used to encode values in this enum table.
Returns the integer code for :firm_cont.
Returns the integer code for :firm_first.
Returns the integer code for :firm_last.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Returns the integer code for :ubea_cont.
Returns the integer code for :ubea_first.
Returns the integer code for :ubea_last.
Types
Functions
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
@spec firm_cont() :: non_neg_integer()
Returns the integer code for :firm_cont.
The code is 0x1.
@spec firm_first() :: non_neg_integer()
Returns the integer code for :firm_first.
The code is 0x0.
@spec firm_last() :: non_neg_integer()
Returns the integer code for :firm_last.
The code is 0x2.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.
@spec ubea_cont() :: non_neg_integer()
Returns the integer code for :ubea_cont.
The code is 0x4.
@spec ubea_first() :: non_neg_integer()
Returns the integer code for :ubea_first.
The code is 0x3.
@spec ubea_last() :: non_neg_integer()
Returns the integer code for :ubea_last.
The code is 0x5.