ArtNet. Packet. EnumTable. RdmCommand
(ArtNet v0.1.0)
ArtRdm command values used by ArtNet.Packet.ArtRdm.
Values
| Atom | Description | Value |
|---|---|---|
ar_process | Process the embedded RDM data. | 0x0 / 0b00000000 |
Summary
Functions
Returns the integer code for :ar_process.
Returns the number of bits used to encode values in this enum table.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Types
Functions
@spec ar_process() :: non_neg_integer()
Returns the integer code for :ar_process.
The code is 0x0.
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.