ArtNet.Packet.EnumTable.TodControlCommand (ArtNet v0.1.0)

TOD control command values used by ArtNet.Packet.ArtTodControl.

Values

AtomDescriptionValue
atc_noneNo control command.0x0 / 0b00000000
atc_flushFlush the Table of Devices.0x1 / 0b00000001
atc_endEnd TOD control.0x2 / 0b00000010
atc_inc_onEnable incremental discovery.0x3 / 0b00000011
atc_inc_offDisable incremental discovery.0x4 / 0b00000100

Summary

Functions

Returns the integer code for :atc_end.

Returns the integer code for :atc_flush.

Returns the integer code for :atc_inc_off.

Returns the integer code for :atc_inc_on.

Returns the integer code for :atc_none.

Returns the number of bits used to encode values in this enum table.

Converts an integer code into its enum atom.

Converts an enum atom into its integer code.

Types

type()

@type type() :: :atc_none | :atc_flush | :atc_end | :atc_inc_on | :atc_inc_off

Functions

atc_end()

@spec atc_end() :: non_neg_integer()

Returns the integer code for :atc_end.

The code is 0x2.

atc_flush()

@spec atc_flush() :: non_neg_integer()

Returns the integer code for :atc_flush.

The code is 0x1.

atc_inc_off()

@spec atc_inc_off() :: non_neg_integer()

Returns the integer code for :atc_inc_off.

The code is 0x4.

atc_inc_on()

@spec atc_inc_on() :: non_neg_integer()

Returns the integer code for :atc_inc_on.

The code is 0x3.

atc_none()

@spec atc_none() :: non_neg_integer()

Returns the integer code for :atc_none.

The code is 0x0.

bit_size()

@spec bit_size() :: pos_integer()

Returns the number of bits used to encode values in this enum table.

to_atom(code)

@spec to_atom(term()) :: {:ok, type()} | :error

Converts an integer code into its enum atom.

Returns {:ok, atom} when the code is defined by this enum table, or :error otherwise.

to_code(value)

@spec to_code(term()) :: {:ok, non_neg_integer()} | :error

Converts an enum atom into its integer code.

Returns {:ok, code} when the atom is defined by this enum table, or :error otherwise.