ArtNet. Packet. EnumTable. TodDataCommandResponse
(ArtNet v0.1.0)
TOD data command response values used by ArtNet.Packet.ArtTodData.
Values
| Atom | Description | Value |
|---|---|---|
tod_full | Packet contains a full Table of Devices response. | 0x0 / 0b00000000 |
tod_nak | Request was rejected. | 0xFF / 0b11111111 |
Summary
Functions
Returns the number of bits used to encode values in this enum table.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Returns the integer code for :tod_full.
Returns the integer code for :tod_nak.
Types
Functions
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.
@spec tod_full() :: non_neg_integer()
Returns the integer code for :tod_full.
The code is 0x0.
@spec tod_nak() :: non_neg_integer()
Returns the integer code for :tod_nak.
The code is 0xFF.