ArtNet. OpCode
(ArtNet v0.1.0)
OpCode registry for supported Art-Net packet modules.
The packet codec uses this module to translate between the little-endian OpCode value in a binary packet, the public OpCode atom, and the packet module that owns the schema.
Summary
Functions
Returns the integer OpCode for a supported OpCode atom or packet module.
Returns the OpCode atom for the given integer code.
Returns the Packet module for the given op code.
Types
@type type() ::
:op_rdm
| :op_rdm_sub
| :op_nzs
| :op_media_control_reply
| :op_mac_master
| :op_address
| :op_data_request
| :op_video_setup
| :op_video_data
| :op_poll_reply
| :op_directory
| :op_poll
| :op_time_code
| :op_file_fn_master
| :op_tod_request
| :op_ip_prog
| :op_firmware_reply
| :op_data_reply
| :op_media_control
| :op_input
| :op_firmware_master
| :op_media
| :op_command
| :op_mac_slave
| :op_tod_control
| :op_trigger
| :op_tod_data
| :op_media_patch
| :op_video_palette
| :op_sync
| :op_diag_data
| :op_ip_prog_reply
| :op_dmx
| :op_directory_reply
| :op_file_fn_reply
| :op_file_tn_master
| :op_time_sync
Supported Art-Net OpCode atoms.
Functions
@spec op_code(type() | module()) :: pos_integer()
Returns the integer OpCode for a supported OpCode atom or packet module.
@spec op_code_type(pos_integer()) :: type() | nil
Returns the OpCode atom for the given integer code.
If the op code is not supported, nil is returned.
@spec packet_module_from_value(pos_integer()) :: module() | nil
Returns the Packet module for the given op code.
If the op code is not supported, nil is returned.