ArtNet. Packet. BitField. IpProgStatus
(ArtNet v0.1.0)
Status bit field used by ArtNet.Packet.ArtIpProgReply.
This field reports IP programming status from a node.
Bit size
This bit field is encoded in 8 bits.
Bit layout
| Field | Description | Bits | Default | Value |
|---|---|---|---|---|
dhcp_enabled | DHCP is enabled on the node. | 6 | false | boolean flag |
Summary
Functions
Returns the bit-field schema in declaration order.
Returns the total number of bits encoded by this bit field.
Decodes an unsigned integer into this bit-field struct.
Encodes this bit-field struct into an unsigned integer.
Types
Functions
@spec bit_field_schema() :: [ {key :: atom(), {ArtNet.Packet.BitField.schema_type(), {start_bit :: non_neg_integer(), length :: pos_integer()}}} ]
Returns the bit-field schema in declaration order.
@spec bit_size() :: pos_integer()
Returns the total number of bits encoded by this bit field.
This bit field is encoded in 8 bits.
@spec decode(non_neg_integer()) :: {:ok, t()} | :error
Decodes an unsigned integer into this bit-field struct.
@spec encode(t()) :: {:ok, non_neg_integer()} | :error
Encodes this bit-field struct into an unsigned integer.