ArtNet. Packet. BitField. Status2
(ArtNet v0.1.0)
Status2 bit field used by ArtNet.Packet.ArtPollReply.
This field reports additional node capabilities and runtime state.
Bit size
This bit field is encoded in 8 bits.
Bit layout
| Field | Description | Bits | Default | Value |
|---|---|---|---|---|
support_browser | Node supports web browser configuration. | 0 | required | boolean flag |
dhcp | Node is currently using DHCP. | 1 | required | boolean flag |
dhcp_capable | Node can use DHCP. | 2 | required | boolean flag |
port_15bit | Node supports 15-bit Port-Address fields. | 3 | required | boolean flag |
can_switch | Output style can be switched. | 4 | required | boolean flag |
squawking | Node is currently squawking. | 5 | required | boolean flag |
switch_output_style | Output style switch is active. | 6 | required | boolean flag |
control_rdm | RDM can be controlled. | 7 | required | boolean flag |
Summary
Functions
Returns the bit-field schema in declaration order.
Returns the total number of bits encoded by this bit field.
Decodes an unsigned integer into this bit-field struct.
Encodes this bit-field struct into an unsigned integer.
Types
Functions
@spec bit_field_schema() :: [ {key :: atom(), {ArtNet.Packet.BitField.schema_type(), {start_bit :: non_neg_integer(), length :: pos_integer()}}} ]
Returns the bit-field schema in declaration order.
@spec bit_size() :: pos_integer()
Returns the total number of bits encoded by this bit field.
This bit field is encoded in 8 bits.
@spec decode(non_neg_integer()) :: {:ok, t()} | :error
Decodes an unsigned integer into this bit-field struct.
@spec encode(t()) :: {:ok, non_neg_integer()} | :error
Encodes this bit-field struct into an unsigned integer.