ArtNet. Packet. BitField. Status3
(ArtNet v0.1.0)
Status3 bit field used by ArtNet.Packet.ArtPollReply.
This field reports newer discovery, RDMnet, LLRP, and failsafe capabilities.
Bit size
This bit field is encoded in 8 bits.
Bit layout
| Field | Description | Bits | Default | Value |
|---|---|---|---|---|
background_discovery_control | Background discovery can be controlled. | 0 | false | boolean flag |
background_queue | Background discovery queue is supported. | 1 | false | boolean flag |
rdmnet | RDMnet is supported. | 2 | false | boolean flag |
port_direction_switch | Port direction can be switched. | 3 | false | boolean flag |
llrp | LLRP is supported. | 4 | false | boolean flag |
programmable_failsafe | Failsafe behavior can be programmed. | 5 | false | boolean flag |
failsafe_state | Active failsafe state reported by ArtNet.Packet.EnumTable.FailsafeState. | 6..7 | :hold_last | ArtNet.Packet.EnumTable.FailsafeState enum (2 bits) |
Summary
Functions
Returns the bit-field schema in declaration order.
Returns the total number of bits encoded by this bit field.
Decodes an unsigned integer into this bit-field struct.
Encodes this bit-field struct into an unsigned integer.
Types
@type t() :: %ArtNet.Packet.BitField.Status3{ background_discovery_control: :boolean, background_queue: :boolean, failsafe_state: ArtNet.Packet.EnumTable.FailsafeState.type(), llrp: :boolean, port_direction_switch: :boolean, programmable_failsafe: :boolean, rdmnet: :boolean }
Functions
@spec bit_field_schema() :: [ {key :: atom(), {ArtNet.Packet.BitField.schema_type(), {start_bit :: non_neg_integer(), length :: pos_integer()}}} ]
Returns the bit-field schema in declaration order.
@spec bit_size() :: pos_integer()
Returns the total number of bits encoded by this bit field.
This bit field is encoded in 8 bits.
@spec decode(non_neg_integer()) :: {:ok, t()} | :error
Decodes an unsigned integer into this bit-field struct.
@spec encode(t()) :: {:ok, non_neg_integer()} | :error
Encodes this bit-field struct into an unsigned integer.