ArtNet. Packet. EnumTable. AddressCommand
(ArtNet v0.1.0)
Address command values used by ArtNet.Packet.ArtAddress.
These values encode the command byte that changes node state or per-port behavior.
Values
| Atom | Description | Value |
|---|---|---|
ac_none | No command. | 0x0 / 0b00000000 |
ac_cancel_merge | Cancel merge mode. | 0x1 / 0b00000001 |
ac_led_normal | Set indicator LEDs to normal. | 0x2 / 0b00000010 |
ac_led_mute | Mute indicator LEDs. | 0x3 / 0b00000011 |
ac_led_locate | Set indicator LEDs to locate. | 0x4 / 0b00000100 |
ac_reset_rx_flags | Reset receiver status flags. | 0x5 / 0b00000101 |
ac_analysis_on | Enable analysis mode. | 0x6 / 0b00000110 |
ac_analysis_off | Disable analysis mode. | 0x7 / 0b00000111 |
ac_fail_hold | Set failsafe behavior to hold last output. | 0x8 / 0b00001000 |
ac_fail_zero | Set failsafe behavior to all zero. | 0x9 / 0b00001001 |
ac_fail_full | Set failsafe behavior to all full. | 0xA / 0b00001010 |
ac_fail_scene | Set failsafe behavior to playback scene. | 0xB / 0b00001011 |
ac_fail_record | Record the failsafe scene. | 0xC / 0b00001100 |
ac_merge_ltp0 | Set output port 0 to LTP merge. | 0x10 / 0b00010000 |
ac_merge_ltp1 | Set output port 1 to LTP merge. | 0x11 / 0b00010001 |
ac_merge_ltp2 | Set output port 2 to LTP merge. | 0x12 / 0b00010010 |
ac_merge_ltp3 | Set output port 3 to LTP merge. | 0x13 / 0b00010011 |
ac_direction_tx0 | Set port 0 to output. | 0x20 / 0b00100000 |
ac_direction_tx1 | Set port 1 to output. | 0x21 / 0b00100001 |
ac_direction_tx2 | Set port 2 to output. | 0x22 / 0b00100010 |
ac_direction_tx3 | Set port 3 to output. | 0x23 / 0b00100011 |
ac_direction_rx0 | Set port 0 to input. | 0x30 / 0b00110000 |
ac_direction_rx1 | Set port 1 to input. | 0x31 / 0b00110001 |
ac_direction_rx2 | Set port 2 to input. | 0x32 / 0b00110010 |
ac_direction_rx3 | Set port 3 to input. | 0x33 / 0b00110011 |
ac_merge_htp0 | Set output port 0 to HTP merge. | 0x50 / 0b01010000 |
ac_merge_htp1 | Set output port 1 to HTP merge. | 0x51 / 0b01010001 |
ac_merge_htp2 | Set output port 2 to HTP merge. | 0x52 / 0b01010010 |
ac_merge_htp3 | Set output port 3 to HTP merge. | 0x53 / 0b01010011 |
ac_art_net_sel0 | Select Art-Net input for port 0. | 0x60 / 0b01100000 |
ac_art_net_sel1 | Select Art-Net input for port 1. | 0x61 / 0b01100001 |
ac_art_net_sel2 | Select Art-Net input for port 2. | 0x62 / 0b01100010 |
ac_art_net_sel3 | Select Art-Net input for port 3. | 0x63 / 0b01100011 |
ac_acn_sel0 | Select sACN input for port 0. | 0x70 / 0b01110000 |
ac_acn_sel1 | Select sACN input for port 1. | 0x71 / 0b01110001 |
ac_acn_sel2 | Select sACN input for port 2. | 0x72 / 0b01110010 |
ac_acn_sel3 | Select sACN input for port 3. | 0x73 / 0b01110011 |
ac_clear_op0 | Clear output state for port 0. | 0x90 / 0b10010000 |
ac_clear_op1 | Clear output state for port 1. | 0x91 / 0b10010001 |
ac_clear_op2 | Clear output state for port 2. | 0x92 / 0b10010010 |
ac_clear_op3 | Clear output state for port 3. | 0x93 / 0b10010011 |
ac_style_delta0 | Select delta output style for port 0. | 0xA0 / 0b10100000 |
ac_style_delta1 | Select delta output style for port 1. | 0xA1 / 0b10100001 |
ac_style_delta2 | Select delta output style for port 2. | 0xA2 / 0b10100010 |
ac_style_delta3 | Select delta output style for port 3. | 0xA3 / 0b10100011 |
ac_style_const0 | Select constant output style for port 0. | 0xB0 / 0b10110000 |
ac_style_const1 | Select constant output style for port 1. | 0xB1 / 0b10110001 |
ac_style_const2 | Select constant output style for port 2. | 0xB2 / 0b10110010 |
ac_style_const3 | Select constant output style for port 3. | 0xB3 / 0b10110011 |
ac_rdm_enable0 | Enable RDM on port 0. | 0xC0 / 0b11000000 |
ac_rdm_enable1 | Enable RDM on port 1. | 0xC1 / 0b11000001 |
ac_rdm_enable2 | Enable RDM on port 2. | 0xC2 / 0b11000010 |
ac_rdm_enable3 | Enable RDM on port 3. | 0xC3 / 0b11000011 |
ac_rdm_disable0 | Disable RDM on port 0. | 0xD0 / 0b11010000 |
ac_rdm_disable1 | Disable RDM on port 1. | 0xD1 / 0b11010001 |
ac_rdm_disable2 | Disable RDM on port 2. | 0xD2 / 0b11010010 |
ac_rdm_disable3 | Disable RDM on port 3. | 0xD3 / 0b11010011 |
ac_bqp0 | Configure the BQP value to 0. | 0xE0 / 0b11100000 |
ac_bqp1 | Configure the BQP value to 1. | 0xE1 / 0b11100001 |
ac_bqp2 | Configure the BQP value to 2. | 0xE2 / 0b11100010 |
ac_bqp3 | Configure the BQP value to 3. | 0xE3 / 0b11100011 |
ac_bqp4 | Configure the BQP value to 4. | 0xE4 / 0b11100100 |
ac_bqp5 | Configure the BQP value to 5. | 0xE5 / 0b11100101 |
ac_bqp6 | Configure the BQP value to 6. | 0xE6 / 0b11100110 |
ac_bqp7 | Configure the BQP value to 7. | 0xE7 / 0b11100111 |
ac_bqp8 | Configure the BQP value to 8. | 0xE8 / 0b11101000 |
ac_bqp9 | Configure the BQP value to 9. | 0xE9 / 0b11101001 |
ac_bqp10 | Configure the BQP value to 10. | 0xEA / 0b11101010 |
ac_bqp11 | Configure the BQP value to 11. | 0xEB / 0b11101011 |
ac_bqp12 | Configure the BQP value to 12. | 0xEC / 0b11101100 |
ac_bqp13 | Configure the BQP value to 13. | 0xED / 0b11101101 |
ac_bqp14 | Configure the BQP value to 14. | 0xEE / 0b11101110 |
ac_bqp15 | Configure the BQP value to 15. | 0xEF / 0b11101111 |
Summary
Functions
Returns the integer code for :ac_acn_sel0.
Returns the integer code for :ac_acn_sel1.
Returns the integer code for :ac_acn_sel2.
Returns the integer code for :ac_acn_sel3.
Returns the integer code for :ac_analysis_off.
Returns the integer code for :ac_analysis_on.
Returns the integer code for :ac_art_net_sel0.
Returns the integer code for :ac_art_net_sel1.
Returns the integer code for :ac_art_net_sel2.
Returns the integer code for :ac_art_net_sel3.
Returns the integer code for :ac_bqp0.
Returns the integer code for :ac_bqp1.
Returns the integer code for :ac_bqp2.
Returns the integer code for :ac_bqp3.
Returns the integer code for :ac_bqp4.
Returns the integer code for :ac_bqp5.
Returns the integer code for :ac_bqp6.
Returns the integer code for :ac_bqp7.
Returns the integer code for :ac_bqp8.
Returns the integer code for :ac_bqp9.
Returns the integer code for :ac_bqp10.
Returns the integer code for :ac_bqp11.
Returns the integer code for :ac_bqp12.
Returns the integer code for :ac_bqp13.
Returns the integer code for :ac_bqp14.
Returns the integer code for :ac_bqp15.
Returns the integer code for :ac_cancel_merge.
Returns the integer code for :ac_clear_op0.
Returns the integer code for :ac_clear_op1.
Returns the integer code for :ac_clear_op2.
Returns the integer code for :ac_clear_op3.
Returns the integer code for :ac_direction_rx0.
Returns the integer code for :ac_direction_rx1.
Returns the integer code for :ac_direction_rx2.
Returns the integer code for :ac_direction_rx3.
Returns the integer code for :ac_direction_tx0.
Returns the integer code for :ac_direction_tx1.
Returns the integer code for :ac_direction_tx2.
Returns the integer code for :ac_direction_tx3.
Returns the integer code for :ac_fail_full.
Returns the integer code for :ac_fail_hold.
Returns the integer code for :ac_fail_record.
Returns the integer code for :ac_fail_scene.
Returns the integer code for :ac_fail_zero.
Returns the integer code for :ac_led_locate.
Returns the integer code for :ac_led_mute.
Returns the integer code for :ac_led_normal.
Returns the integer code for :ac_merge_htp0.
Returns the integer code for :ac_merge_htp1.
Returns the integer code for :ac_merge_htp2.
Returns the integer code for :ac_merge_htp3.
Returns the integer code for :ac_merge_ltp0.
Returns the integer code for :ac_merge_ltp1.
Returns the integer code for :ac_merge_ltp2.
Returns the integer code for :ac_merge_ltp3.
Returns the integer code for :ac_none.
Returns the integer code for :ac_rdm_disable0.
Returns the integer code for :ac_rdm_disable1.
Returns the integer code for :ac_rdm_disable2.
Returns the integer code for :ac_rdm_disable3.
Returns the integer code for :ac_rdm_enable0.
Returns the integer code for :ac_rdm_enable1.
Returns the integer code for :ac_rdm_enable2.
Returns the integer code for :ac_rdm_enable3.
Returns the integer code for :ac_reset_rx_flags.
Returns the integer code for :ac_style_const0.
Returns the integer code for :ac_style_const1.
Returns the integer code for :ac_style_const2.
Returns the integer code for :ac_style_const3.
Returns the integer code for :ac_style_delta0.
Returns the integer code for :ac_style_delta1.
Returns the integer code for :ac_style_delta2.
Returns the integer code for :ac_style_delta3.
Returns the number of bits used to encode values in this enum table.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Types
@type type() ::
:ac_none
| :ac_cancel_merge
| :ac_led_normal
| :ac_led_mute
| :ac_led_locate
| :ac_reset_rx_flags
| :ac_analysis_on
| :ac_analysis_off
| :ac_fail_hold
| :ac_fail_zero
| :ac_fail_full
| :ac_fail_scene
| :ac_fail_record
| :ac_merge_ltp0
| :ac_merge_ltp1
| :ac_merge_ltp2
| :ac_merge_ltp3
| :ac_direction_tx0
| :ac_direction_tx1
| :ac_direction_tx2
| :ac_direction_tx3
| :ac_direction_rx0
| :ac_direction_rx1
| :ac_direction_rx2
| :ac_direction_rx3
| :ac_merge_htp0
| :ac_merge_htp1
| :ac_merge_htp2
| :ac_merge_htp3
| :ac_art_net_sel0
| :ac_art_net_sel1
| :ac_art_net_sel2
| :ac_art_net_sel3
| :ac_acn_sel0
| :ac_acn_sel1
| :ac_acn_sel2
| :ac_acn_sel3
| :ac_clear_op0
| :ac_clear_op1
| :ac_clear_op2
| :ac_clear_op3
| :ac_style_delta0
| :ac_style_delta1
| :ac_style_delta2
| :ac_style_delta3
| :ac_style_const0
| :ac_style_const1
| :ac_style_const2
| :ac_style_const3
| :ac_rdm_enable0
| :ac_rdm_enable1
| :ac_rdm_enable2
| :ac_rdm_enable3
| :ac_rdm_disable0
| :ac_rdm_disable1
| :ac_rdm_disable2
| :ac_rdm_disable3
| :ac_bqp0
| :ac_bqp1
| :ac_bqp2
| :ac_bqp3
| :ac_bqp4
| :ac_bqp5
| :ac_bqp6
| :ac_bqp7
| :ac_bqp8
| :ac_bqp9
| :ac_bqp10
| :ac_bqp11
| :ac_bqp12
| :ac_bqp13
| :ac_bqp14
| :ac_bqp15
Functions
@spec ac_acn_sel0() :: non_neg_integer()
Returns the integer code for :ac_acn_sel0.
The code is 0x70.
@spec ac_acn_sel1() :: non_neg_integer()
Returns the integer code for :ac_acn_sel1.
The code is 0x71.
@spec ac_acn_sel2() :: non_neg_integer()
Returns the integer code for :ac_acn_sel2.
The code is 0x72.
@spec ac_acn_sel3() :: non_neg_integer()
Returns the integer code for :ac_acn_sel3.
The code is 0x73.
@spec ac_analysis_off() :: non_neg_integer()
Returns the integer code for :ac_analysis_off.
The code is 0x7.
@spec ac_analysis_on() :: non_neg_integer()
Returns the integer code for :ac_analysis_on.
The code is 0x6.
@spec ac_art_net_sel0() :: non_neg_integer()
Returns the integer code for :ac_art_net_sel0.
The code is 0x60.
@spec ac_art_net_sel1() :: non_neg_integer()
Returns the integer code for :ac_art_net_sel1.
The code is 0x61.
@spec ac_art_net_sel2() :: non_neg_integer()
Returns the integer code for :ac_art_net_sel2.
The code is 0x62.
@spec ac_art_net_sel3() :: non_neg_integer()
Returns the integer code for :ac_art_net_sel3.
The code is 0x63.
@spec ac_bqp0() :: non_neg_integer()
Returns the integer code for :ac_bqp0.
The code is 0xE0.
@spec ac_bqp1() :: non_neg_integer()
Returns the integer code for :ac_bqp1.
The code is 0xE1.
@spec ac_bqp2() :: non_neg_integer()
Returns the integer code for :ac_bqp2.
The code is 0xE2.
@spec ac_bqp3() :: non_neg_integer()
Returns the integer code for :ac_bqp3.
The code is 0xE3.
@spec ac_bqp4() :: non_neg_integer()
Returns the integer code for :ac_bqp4.
The code is 0xE4.
@spec ac_bqp5() :: non_neg_integer()
Returns the integer code for :ac_bqp5.
The code is 0xE5.
@spec ac_bqp6() :: non_neg_integer()
Returns the integer code for :ac_bqp6.
The code is 0xE6.
@spec ac_bqp7() :: non_neg_integer()
Returns the integer code for :ac_bqp7.
The code is 0xE7.
@spec ac_bqp8() :: non_neg_integer()
Returns the integer code for :ac_bqp8.
The code is 0xE8.
@spec ac_bqp9() :: non_neg_integer()
Returns the integer code for :ac_bqp9.
The code is 0xE9.
@spec ac_bqp10() :: non_neg_integer()
Returns the integer code for :ac_bqp10.
The code is 0xEA.
@spec ac_bqp11() :: non_neg_integer()
Returns the integer code for :ac_bqp11.
The code is 0xEB.
@spec ac_bqp12() :: non_neg_integer()
Returns the integer code for :ac_bqp12.
The code is 0xEC.
@spec ac_bqp13() :: non_neg_integer()
Returns the integer code for :ac_bqp13.
The code is 0xED.
@spec ac_bqp14() :: non_neg_integer()
Returns the integer code for :ac_bqp14.
The code is 0xEE.
@spec ac_bqp15() :: non_neg_integer()
Returns the integer code for :ac_bqp15.
The code is 0xEF.
@spec ac_cancel_merge() :: non_neg_integer()
Returns the integer code for :ac_cancel_merge.
The code is 0x1.
@spec ac_clear_op0() :: non_neg_integer()
Returns the integer code for :ac_clear_op0.
The code is 0x90.
@spec ac_clear_op1() :: non_neg_integer()
Returns the integer code for :ac_clear_op1.
The code is 0x91.
@spec ac_clear_op2() :: non_neg_integer()
Returns the integer code for :ac_clear_op2.
The code is 0x92.
@spec ac_clear_op3() :: non_neg_integer()
Returns the integer code for :ac_clear_op3.
The code is 0x93.
@spec ac_direction_rx0() :: non_neg_integer()
Returns the integer code for :ac_direction_rx0.
The code is 0x30.
@spec ac_direction_rx1() :: non_neg_integer()
Returns the integer code for :ac_direction_rx1.
The code is 0x31.
@spec ac_direction_rx2() :: non_neg_integer()
Returns the integer code for :ac_direction_rx2.
The code is 0x32.
@spec ac_direction_rx3() :: non_neg_integer()
Returns the integer code for :ac_direction_rx3.
The code is 0x33.
@spec ac_direction_tx0() :: non_neg_integer()
Returns the integer code for :ac_direction_tx0.
The code is 0x20.
@spec ac_direction_tx1() :: non_neg_integer()
Returns the integer code for :ac_direction_tx1.
The code is 0x21.
@spec ac_direction_tx2() :: non_neg_integer()
Returns the integer code for :ac_direction_tx2.
The code is 0x22.
@spec ac_direction_tx3() :: non_neg_integer()
Returns the integer code for :ac_direction_tx3.
The code is 0x23.
@spec ac_fail_full() :: non_neg_integer()
Returns the integer code for :ac_fail_full.
The code is 0xA.
@spec ac_fail_hold() :: non_neg_integer()
Returns the integer code for :ac_fail_hold.
The code is 0x8.
@spec ac_fail_record() :: non_neg_integer()
Returns the integer code for :ac_fail_record.
The code is 0xC.
@spec ac_fail_scene() :: non_neg_integer()
Returns the integer code for :ac_fail_scene.
The code is 0xB.
@spec ac_fail_zero() :: non_neg_integer()
Returns the integer code for :ac_fail_zero.
The code is 0x9.
@spec ac_led_locate() :: non_neg_integer()
Returns the integer code for :ac_led_locate.
The code is 0x4.
@spec ac_led_mute() :: non_neg_integer()
Returns the integer code for :ac_led_mute.
The code is 0x3.
@spec ac_led_normal() :: non_neg_integer()
Returns the integer code for :ac_led_normal.
The code is 0x2.
@spec ac_merge_htp0() :: non_neg_integer()
Returns the integer code for :ac_merge_htp0.
The code is 0x50.
@spec ac_merge_htp1() :: non_neg_integer()
Returns the integer code for :ac_merge_htp1.
The code is 0x51.
@spec ac_merge_htp2() :: non_neg_integer()
Returns the integer code for :ac_merge_htp2.
The code is 0x52.
@spec ac_merge_htp3() :: non_neg_integer()
Returns the integer code for :ac_merge_htp3.
The code is 0x53.
@spec ac_merge_ltp0() :: non_neg_integer()
Returns the integer code for :ac_merge_ltp0.
The code is 0x10.
@spec ac_merge_ltp1() :: non_neg_integer()
Returns the integer code for :ac_merge_ltp1.
The code is 0x11.
@spec ac_merge_ltp2() :: non_neg_integer()
Returns the integer code for :ac_merge_ltp2.
The code is 0x12.
@spec ac_merge_ltp3() :: non_neg_integer()
Returns the integer code for :ac_merge_ltp3.
The code is 0x13.
@spec ac_none() :: non_neg_integer()
Returns the integer code for :ac_none.
The code is 0x0.
@spec ac_rdm_disable0() :: non_neg_integer()
Returns the integer code for :ac_rdm_disable0.
The code is 0xD0.
@spec ac_rdm_disable1() :: non_neg_integer()
Returns the integer code for :ac_rdm_disable1.
The code is 0xD1.
@spec ac_rdm_disable2() :: non_neg_integer()
Returns the integer code for :ac_rdm_disable2.
The code is 0xD2.
@spec ac_rdm_disable3() :: non_neg_integer()
Returns the integer code for :ac_rdm_disable3.
The code is 0xD3.
@spec ac_rdm_enable0() :: non_neg_integer()
Returns the integer code for :ac_rdm_enable0.
The code is 0xC0.
@spec ac_rdm_enable1() :: non_neg_integer()
Returns the integer code for :ac_rdm_enable1.
The code is 0xC1.
@spec ac_rdm_enable2() :: non_neg_integer()
Returns the integer code for :ac_rdm_enable2.
The code is 0xC2.
@spec ac_rdm_enable3() :: non_neg_integer()
Returns the integer code for :ac_rdm_enable3.
The code is 0xC3.
@spec ac_reset_rx_flags() :: non_neg_integer()
Returns the integer code for :ac_reset_rx_flags.
The code is 0x5.
@spec ac_style_const0() :: non_neg_integer()
Returns the integer code for :ac_style_const0.
The code is 0xB0.
@spec ac_style_const1() :: non_neg_integer()
Returns the integer code for :ac_style_const1.
The code is 0xB1.
@spec ac_style_const2() :: non_neg_integer()
Returns the integer code for :ac_style_const2.
The code is 0xB2.
@spec ac_style_const3() :: non_neg_integer()
Returns the integer code for :ac_style_const3.
The code is 0xB3.
@spec ac_style_delta0() :: non_neg_integer()
Returns the integer code for :ac_style_delta0.
The code is 0xA0.
@spec ac_style_delta1() :: non_neg_integer()
Returns the integer code for :ac_style_delta1.
The code is 0xA1.
@spec ac_style_delta2() :: non_neg_integer()
Returns the integer code for :ac_style_delta2.
The code is 0xA2.
@spec ac_style_delta3() :: non_neg_integer()
Returns the integer code for :ac_style_delta3.
The code is 0xA3.
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.