ArtNet. Packet. EnumTable. Priority
(ArtNet v0.1.0)
Diagnostic priority values used by ArtNet.Packet.ArtPoll and
ArtNet.Packet.ArtDiagData.
Values
| Atom | Description | Value |
|---|---|---|
dp_all | All diagnostic messages. | 0x0 / 0b00000000 |
dp_low | Low priority and above. | 0x10 / 0b00010000 |
dp_med | Medium priority and above. | 0x40 / 0b01000000 |
dp_high | High priority and above. | 0x80 / 0b10000000 |
dp_critical | Critical messages only. | 0xE0 / 0b11100000 |
dp_volatile | Volatile messages. | 0xF0 / 0b11110000 |
Summary
Functions
Returns the number of bits used to encode values in this enum table.
Returns the integer code for :dp_all.
Returns the integer code for :dp_critical.
Returns the integer code for :dp_high.
Returns the integer code for :dp_low.
Returns the integer code for :dp_med.
Returns the integer code for :dp_volatile.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Types
Functions
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
@spec dp_all() :: non_neg_integer()
Returns the integer code for :dp_all.
The code is 0x0.
@spec dp_critical() :: non_neg_integer()
Returns the integer code for :dp_critical.
The code is 0xE0.
@spec dp_high() :: non_neg_integer()
Returns the integer code for :dp_high.
The code is 0x80.
@spec dp_low() :: non_neg_integer()
Returns the integer code for :dp_low.
The code is 0x10.
@spec dp_med() :: non_neg_integer()
Returns the integer code for :dp_med.
The code is 0x40.
@spec dp_volatile() :: non_neg_integer()
Returns the integer code for :dp_volatile.
The code is 0xF0.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.