ArtNet. Packet. EnumTable. RdmCommandClass
(ArtNet v0.1.0)
RDM command class values used by ArtNet.Packet.ArtRdmSub.
Values
| Atom | Description | Value |
|---|---|---|
discovery_command | RDM discovery command. | 0x10 / 0b00010000 |
discovery_command_response | Response to a discovery command. | 0x11 / 0b00010001 |
get_command | RDM get command. | 0x20 / 0b00100000 |
get_response | Response to a get command. | 0x21 / 0b00100001 |
set_command | RDM set command. | 0x30 / 0b00110000 |
set_response | Response to a set command. | 0x31 / 0b00110001 |
Summary
Functions
Returns the number of bits used to encode values in this enum table.
Returns the integer code for :discovery_command.
Returns the integer code for :discovery_command_response.
Returns the integer code for :get_command.
Returns the integer code for :get_response.
Returns the integer code for :set_command.
Returns the integer code for :set_response.
Converts an integer code into its enum atom.
Converts an enum atom into its integer code.
Types
Functions
@spec bit_size() :: pos_integer()
Returns the number of bits used to encode values in this enum table.
@spec discovery_command() :: non_neg_integer()
Returns the integer code for :discovery_command.
The code is 0x10.
@spec discovery_command_response() :: non_neg_integer()
Returns the integer code for :discovery_command_response.
The code is 0x11.
@spec get_command() :: non_neg_integer()
Returns the integer code for :get_command.
The code is 0x20.
@spec get_response() :: non_neg_integer()
Returns the integer code for :get_response.
The code is 0x21.
@spec set_command() :: non_neg_integer()
Returns the integer code for :set_command.
The code is 0x30.
@spec set_response() :: non_neg_integer()
Returns the integer code for :set_response.
The code is 0x31.
Converts an integer code into its enum atom.
Returns {:ok, atom} when the code is defined by this enum table, or
:error otherwise.
@spec to_code(term()) :: {:ok, non_neg_integer()} | :error
Converts an enum atom into its integer code.
Returns {:ok, code} when the atom is defined by this enum table, or
:error otherwise.